@@ -3,7 +3,7 @@ import json
 import logging
 
 import socketio
-from aiortc import MediaStreamTrack, RTCPeerConnection
+from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
 
@@ -27,6 +27,14 @@ class GSPeerConnectionWatcher:
     @classmethod
     async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None):
         self = GSPeerConnectionWatcher()
+        rtconfiList = []
+        if self.gsdbs.credentials["stunEnable"]:
+            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
+        if self.gsdbs.credentials["turnenable"]:
+            rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
+                                            self.gsdbs.credentials["turnuser"],
+                                            self.gsdbs.credentials["turnpw"]))
+
         self.sio = socketio.AsyncClient()
         self.gsdbs = gsdbs
         self.onframe = onframe
@@ -49,7 +57,10 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def offer(id, description):
-            self.peerConnections = RTCPeerConnection()
+            if len(rtconfiList) > 0:
+                pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
+            else:
+                pc = RTCPeerConnection()
 
             @self.peerConnections.on("datachannel")
             def on_datachannel(channel):
@@ -66,7 +77,7 @@ class GSPeerConnectionWatcher:
             async def on_track(track):
                 if track.kind == "video":
                     if self.ontrack is not None:
-                        await self.ontrack(self.gsdbs, track,target)
+                        await self.ontrack(self.gsdbs, track, self.target)
 
                 @track.on("ended")
                 async def on_ended():
